.. currentmodule:: brainsets

brainsets.descriptions
---------------------

.. list-table::
   :widths: 25 125
   :align: left

   * - :obj:`BrainsetDescription <brainsets.descriptions.BrainsetDescription>`
     - A class for describing a brainset
   * - :obj:`SubjectDescription <brainsets.descriptions.SubjectDescription>`
     - A class for describing a subject
   * - :obj:`SessionDescription <brainsets.descriptions.SessionDescription>`
     - A class for describing an experimental session
   * - :obj:`DeviceDescription <brainsets.descriptions.DeviceDescription>`
     - A class for describing a recording device


.. autoclass:: brainsets.descriptions.BrainsetDescription
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.descriptions.SubjectDescription
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.descriptions.SessionDescription
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.descriptions.DeviceDescription
    :members:
    :show-inheritance:
    :undoc-members:
